==> lxqt-panel-1.4.0-1.src.tar.gz: lxqt-panel-1.4.0/plugin-taskbar/translations/taskbar_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>LXQtTaskBar</name>
    <message>
        <location filename="../lxqttaskbar.cpp" line="681"/>
        <source>Activate task %1</source>
        <translation>Запустити завдання %1</translation>
    </message>
</context>
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="674"/>
        <source>Application</source>
        <translation>Програма</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="708"/>
        <source>To &amp;Desktop</source>
        <translation>На &amp;стільницю</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="710"/>
        <source>&amp;All Desktops</source>
        <translation>На &amp;всі стільниці</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="720"/>
        <source>Desktop &amp;%1</source>
        <translation>Стільниця &amp;%1</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="730"/>
        <source>&amp;To Current Desktop</source>
        <translation>На &amp;поточну стільницю</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="739"/>
        <source>Move To N&amp;ext Monitor</source>
        <translation>Перемістити на н&amp;аступний монітор</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="742"/>
        <source>Move To &amp;Previous Monitor</source>
        <translation>Перемістити до &amp;попереднього монітора</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="746"/>
        <source>&amp;Move</source>
        <translation>&amp;Перемістити</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="749"/>
        <source>Resi&amp;ze</source>
        <translation>&amp;Змінмти розмір</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="756"/>
        <source>Ma&amp;ximize</source>
        <translation>Ма&amp;ксимізувати</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="763"/>
        <source>Maximize vertically</source>
        <translation>Максимізувати вертикально</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="768"/>
        <source>Maximize horizontally</source>
        <translation>Максимізувати горизонтально</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="774"/>
        <source>&amp;Restore</source>
        <translation>&amp;Розгорнути</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="778"/>
        <source>Mi&amp;nimize</source>
        <translation>&amp;Згорнути</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="784"/>
        <source>Roll down</source>
        <translation>Посунути вниз</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="790"/>
        <source>Roll up</source>
        <translation>Посунути вгору</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="798"/>
        <source>&amp;Layer</source>
        <translation>&amp;Шар</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="800"/>
        <source>Always on &amp;top</source>
        <translation>Завжди з&amp;гори</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="806"/>
        <source>&amp;Normal</source>
        <translation>&amp;Типово</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="812"/>
        <source>Always on &amp;bottom</source>
        <translation>Завжди з&amp;низу</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="820"/>
        <source>&amp;Close</source>
        <translation>З&amp;акрити</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="82"/>
        <source>Group</source>
        <translation>Група</translation>
    </message>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="84"/>
        <source>Close group</source>
        <translation>Закрити групу</translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation>Налаштування менеджера завдань</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Загальне</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="43"/>
        <source>Show only windows from desktop</source>
        <translation>Показати лише вікна зі стільниці</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="55"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation>Показати лише вікна з екрана &amp;панелі</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="62"/>
        <source>Show only minimized windows</source>
        <translation>Показати лише згорнуті вікна</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="69"/>
        <source>Raise minimized windows on current desktop</source>
        <translation>Розгорнути мінімізовані вікна на поточній стільниці</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="49"/>
        <source>Cycle windows on wheel scrolling</source>
        <translation>Перемикання між вікнами прокруткою коліщатка</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="143"/>
        <source>Window &amp;grouping</source>
        <translation>Групування &amp;вікон</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="152"/>
        <source>Show popup on mouse hover</source>
        <translation>Попередній перегляд наведенням миші</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="169"/>
        <source>Appearance</source>
        <translation>Вигляд</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="188"/>
        <source>Maximum button width</source>
        <translation>Максимальний розмір кнопки</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="125"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="201"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="227"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="86"/>
        <source>Mouse Wheel</source>
        <translation>Коліщатко миші</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="112"/>
        <source>Wheel Delta Threshold</source>
        <translation>Поріг чутливості коліщатка</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="162"/>
        <source>Put buttons of the same class next to each other</source>
        <translation>Розміщувати кнопки одного класу поруч</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="214"/>
        <source>Maximum button height</source>
        <translation>Найбільша висота кнопки</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="247"/>
        <source>Use icons by WindowClass, if available</source>
        <translation>Використовувати піктограми за WindowClass, якщо доступні</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="240"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation>Авто&amp;повертати кнопки коли панель є вертикальна</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="178"/>
        <source>Button style</source>
        <translation>Стиль кнопок</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="76"/>
        <source>Close on middle-click</source>
        <translation>Закривати по середній кнопці миші</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="44"/>
        <source>Icon and text</source>
        <translation>Піктограма та текст</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="45"/>
        <source>Only icon</source>
        <translation>Лише піктограма</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Only text</source>
        <translation>Лише текст</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="48"/>
        <source>Disabled</source>
        <translation>Вимкнено</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="50"/>
        <source>Scroll up to raise, down to minimize</source>
        <translation>Прокрутити вгору, щоб відновити, вниз, щоб згорнути</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="51"/>
        <source>Scroll up to minimize, down to raise</source>
        <translation>Прокрутити вгору, щоб згорнути, вниз, щоб відновити</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="52"/>
        <source>Scroll up to move to next desktop, down to previous</source>
        <translation>Прокрутити вгору, щоб перемістити на наступну стільницю, вниз — на попередню</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="53"/>
        <source>Scroll up to move to previous desktop, down to next</source>
        <translation>Прокрутити вгору, щоб перемістити на попередню стільницю, вниз — на наступну</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="55"/>
        <source>Current</source>
        <translation>Поточне</translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.1.4-1.src.tar.gz: lxqt-panel-2.1.4/plugin-taskbar/translations/taskbar_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>LXQtTaskBar</name>
    <message>
        <location filename="../lxqttaskbar.cpp" line="649"/>
        <source>Activate task %1</source>
        <translation>Запустити завдання %1</translation>
    </message>
</context>
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="546"/>
        <source>Application</source>
        <translation>Програма</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="580"/>
        <source>To &amp;Desktop</source>
        <translation>На &amp;стільницю</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="583"/>
        <source>&amp;All Desktops</source>
        <translation>На &amp;всі стільниці</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="593"/>
        <source>Desktop &amp;%1</source>
        <translation>Стільниця &amp;%1</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="603"/>
        <source>&amp;To Current Desktop</source>
        <translation>На &amp;поточну стільницю</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="612"/>
        <source>Move To N&amp;ext Monitor</source>
        <translation>Перемістити на н&amp;аступний монітор</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="618"/>
        <source>Move To &amp;Previous Monitor</source>
        <translation>Перемістити до &amp;попереднього монітора</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="624"/>
        <source>&amp;Move</source>
        <translation>&amp;Перемістити</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="629"/>
        <source>Resi&amp;ze</source>
        <translation>&amp;Змінмти розмір</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="638"/>
        <source>Ma&amp;ximize</source>
        <translation>Ма&amp;ксимізувати</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="647"/>
        <source>Maximize vertically</source>
        <translation>Максимізувати вертикально</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="654"/>
        <source>Maximize horizontally</source>
        <translation>Максимізувати горизонтально</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="662"/>
        <source>&amp;Restore</source>
        <translation>&amp;Розгорнути</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="670"/>
        <source>Mi&amp;nimize</source>
        <translation>&amp;Згорнути</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="678"/>
        <source>Roll down</source>
        <translation>Посунути вниз</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="686"/>
        <source>Roll up</source>
        <translation>Посунути вгору</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="695"/>
        <source>&amp;Layer</source>
        <translation>&amp;Шар</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="700"/>
        <source>Always on &amp;top</source>
        <translation>Завжди з&amp;гори</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="705"/>
        <source>&amp;Normal</source>
        <translation>&amp;Типово</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="710"/>
        <source>Always on &amp;bottom</source>
        <translation>Завжди з&amp;низу</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="717"/>
        <source>&amp;Close</source>
        <translation>З&amp;акрити</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="84"/>
        <source>Group</source>
        <translation>Група</translation>
    </message>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="86"/>
        <source>Close group</source>
        <translation>Закрити групу</translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation>Налаштування менеджера завдань</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Загальне</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="43"/>
        <source>Show only windows from desktop</source>
        <translation>Показати лише вікна зі стільниці</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="55"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation>Показати лише вікна з екрана &amp;панелі</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="62"/>
        <source>Show only minimized windows</source>
        <translation>Показати лише згорнуті вікна</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="69"/>
        <source>Raise minimized windows on current desktop</source>
        <translation>Розгорнути мінімізовані вікна на поточній стільниці</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="254"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="264"/>
        <source>Comma separated list of window classes</source>
        <translation>Список класів вікон, розділений комами</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="257"/>
        <source>Exclude from taskbar</source>
        <translation>Виключити з панелі завдань</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="51"/>
        <source>Cycle windows on wheel scrolling</source>
        <translation>Перемикання між вікнами прокруткою коліщатка</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="143"/>
        <source>Window &amp;grouping</source>
        <translation>Групування &amp;вікон</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="152"/>
        <source>Show popup on mouse hover</source>
        <translation>Попередній перегляд наведенням миші</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="169"/>
        <source>Appearance</source>
        <translation>Вигляд</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="188"/>
        <source>Maximum button width</source>
        <translation>Максимальний розмір кнопки</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="125"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="201"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="227"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="86"/>
        <source>Mouse Wheel</source>
        <translation>Коліщатко миші</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="112"/>
        <source>Wheel Delta Threshold</source>
        <translation>Поріг чутливості коліщатка</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="162"/>
        <source>Put buttons of the same class next to each other</source>
        <translation>Розміщувати кнопки одного класу поруч</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="214"/>
        <source>Maximum button height</source>
        <translation>Найбільша висота кнопки</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="247"/>
        <source>Use icons by WindowClass, if available</source>
        <translation>Використовувати піктограми за WindowClass, якщо доступні</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="240"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation>Авто&amp;повертати кнопки коли панель є вертикальна</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="178"/>
        <source>Button style</source>
        <translation>Стиль кнопок</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="76"/>
        <source>Close on middle-click</source>
        <translation>Закривати по середній кнопці миші</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Icon and text</source>
        <translation>Піктограма та текст</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="47"/>
        <source>Only icon</source>
        <translation>Лише піктограма</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="48"/>
        <source>Only text</source>
        <translation>Лише текст</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="50"/>
        <source>Disabled</source>
        <translation>Вимкнено</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="52"/>
        <source>Scroll up to raise, down to minimize</source>
        <translation>Прокрутити вгору, щоб відновити, вниз, щоб згорнути</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="53"/>
        <source>Scroll up to minimize, down to raise</source>
        <translation>Прокрутити вгору, щоб згорнути, вниз, щоб відновити</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="54"/>
        <source>Scroll up to move to next desktop, down to previous</source>
        <translation>Прокрутити вгору, щоб перемістити на наступну стільницю, вниз — на попередню</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="55"/>
        <source>Scroll up to move to previous desktop, down to next</source>
        <translation>Прокрутити вгору, щоб перемістити на попередню стільницю, вниз — на наступну</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="60"/>
        <source>Current</source>
        <translation>Поточне</translation>
    </message>
</context>
</TS>
